% Spindle
%   :PROPERTIES:
%   :header-args:matlab+: :tangle src/initializeRz.m
%   :header-args:matlab+: :comments org :mkdirp yes
%   :header-args:matlab+: :eval no :results none
%   :END:
%   <<sec:initializeRz>>

% This Matlab function is accessible [[file:src/initializeRz.m][here]].


function [rz] = initializeRz(opts_param)
    %% Default values for opts
    opts = struct('rigid', false);

    %% Populate opts with input parameters
    if exist('opts_param','var')
        for opt = fieldnames(opts_param)'
            opts.(opt{1}) = opts_param.(opt{1});
        end
    end

    %%
    rz = struct();

    %% Spindle - Static Properties
    % Spindle - Slip Ring
    rz.slipring.density = 7800; % [kg/m3]
    rz.slipring.color   = [0.792 0.820 0.933];
    rz.slipring.STEP    = './STEPS/rz/Spindle_Slip_Ring.STEP';
    % Spindle - Rotor
    rz.rotor.density    = 7800; % [kg/m3]
    rz.rotor.color      = [0.792 0.820 0.933];
    rz.rotor.STEP       = './STEPS/rz/Spindle_Rotor.STEP';
    % Spindle - Stator
    rz.stator.density   = 7800; % [kg/m3]
    rz.stator.color     = [0.792 0.820 0.933];
    rz.stator.STEP      = './STEPS/rz/Spindle_Stator.STEP';

    % Estimated mass of the mooving part
    rz.m = 250; % [kg]

    %% Spindle - Dynamical Properties
    % Estimated stiffnesses
    rz.k.ax   = 2e9; % Axial Stiffness [N/m]
    rz.k.rad  = 7e8; % Radial Stiffness [N/m]
    rz.k.rot  = 100e6*2*pi/360; % Rotational Stiffness [N*m/deg]

    if opts.rigid
        rz.k.tilt = 1e10; % Vertical Rotational Stiffness [N*m/deg]
    else
        rz.k.tilt = 1e2; % TODO what value should I put? [N*m/deg]
    end

    % TODO
    rz.c.ax   = 2*sqrt(rz.k.ax/rz.m);
    rz.c.rad  = 2*sqrt(rz.k.rad/rz.m);
    rz.c.tilt = 100*sqrt(rz.k.tilt/rz.m);
    rz.c.rot  = 100*sqrt(rz.k.rot/rz.m);

    %% Save
    save('./mat/stages.mat', 'rz', '-append');
end
